@@ -4,6 +4,7 @@
 Module implementing the logging of errors.
 """
 
+import os
 import logging
 import logging.handlers
 
@@ -14,7 +15,11 @@ class CutetubeLog():
     LOGFILE = "/home/user/.config/Stuart Howarth/cuteTube.log"
     logger = logging.getLogger('logger')
     logger.setLevel(logging.DEBUG)
-    handler = logging.handlers.RotatingFileHandler(LOGFILE, maxBytes=30000, backupCount=1)
+    try:
+        handler = logging.handlers.RotatingFileHandler(LOGFILE, maxBytes=30000, backupCount=1)
+    except IOError: # Config directory will not exist if this is the time the application has been run.
+        os.mkdir("/home/user/.config/Stuart Howarth")
+        handler = logging.handlers.RotatingFileHandler(LOGFILE, maxBytes=30000, backupCount=1)
     formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s",  datefmt = "%a, %d %b %Y %H:%M:%S")
     handler.setFormatter(formatter)
     logger.addHandler(handler)
