@@ -12,7 +12,7 @@ from videoinfowindow import VideoInfoWindow
 import customwidgets
 import youtubeservice
 import cutetubedialogs
-from cutetubeconfig import GeneralSettings
+from cutetubeconfig import GeneralSettings, YouTubeAPISettings
 from cutetubelog import CutetubeLog
 from videoplaybackwindow import VideoPlaybackWindow
 
@@ -41,11 +41,11 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         queueLength = len(youtubeservice.YouTubeQueueFeed.playlist)
         if queueLength > 0:
             self.actionGoToQueue.setVisible(True)
-            self.actionGoToQueue.setText("Queue (%s videos)" % unicode(queueLength))
+            self.actionGoToQueue.setText("Queue (%d videos)" % queueLength)
         taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
-            self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
+            self.actionDownloads.setText("Downloads (%d videos)" % taskQueueLength)
         self.connect(closeFilter, SIGNAL("triggered()"), self.closeFilter)
         self.connect(self.actionAddToQueue, SIGNAL("triggered()"), self.addToQueue)
         self.connect(self.actionAddToPlaylist, SIGNAL("triggered()"), self.addToPlaylist)
@@ -184,21 +184,10 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         
     def getMoreResults(self, scrollBarPos):
         """
-        Shows the 'more' button to enable the user to 
-        get more results.
+        Retrieves further results.
         """
-        if self.yt.isFinished() and self.yt.results < self.yt.totalResults and scrollBarPos > (self.yt.results - 10) * 79:
-            self.moreButton.setVisible(True)
-        else:
-            self.moreButton.setVisible(False)
-                
-    @pyqtSignature("")
-    def on_moreButton_clicked(self):
-        """
-        Appends more results to the list
-        """
-        self.loadData()
-        self.moreButton.setVisible(False)
+        if self.yt.isFinished() and self.yt.results < self.yt.totalResults and scrollBarPos > (self.yt.results - 20) * 79:
+            self.loadData()
 
     def reloadData(self):
         """
@@ -207,6 +196,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         """
         self.listWidget.clear()
         self.closeFilter()
+        self.yt.resetResultCount()
         self.loadData()
 
     def addVideo(self, videoData):
@@ -423,7 +413,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         """
         if queueLength > 0:
             self.actionGoToQueue.setVisible(True)
-            self.actionGoToQueue.setText("Queue (%s videos)" % unicode(queueLength))
+            self.actionGoToQueue.setText("Queue (%d videos)" % queueLength)
         else:
             self.actionGoToQueue.setVisible(False)
         self.emit(SIGNAL("queueChanged(int)"), queueLength)
@@ -435,7 +425,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         """
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
-            self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
+            self.actionDownloads.setText("Downloads (%d videos)" % taskQueueLength)
         else:
             self.actionDownloads.setVisible(False)
         self.emit(SIGNAL("downloadsChanged(int)"), taskQueueLength)
@@ -457,7 +447,9 @@ class MostRecentWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.show()
-        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_recent"
+        location = YouTubeAPISettings.locationFilter
+        category = YouTubeAPISettings.categoryFilter
+        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/%smost_recent%s" % (location, category)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
@@ -483,7 +475,9 @@ class MostViewedWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.show()
-        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_viewed?time=today"
+        location = YouTubeAPISettings.locationFilter
+        category = YouTubeAPISettings.categoryFilter
+        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/%smost_viewed%s?time=today" % (location, category)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
@@ -511,12 +505,13 @@ class SearchResultsWindow(CutetubeWindows):
         self.pencilList = []
         self.info = False
         self.show() 
+        locale = YouTubeAPISettings.locale
         searchTerms = self.searchString.replace(" ", "+")
         if username == None:
-            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?vq=%s&orderby=%s" % (searchTerms, searchOrder)
+            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?vq=%s&racy=include&orderby=%s" % (searchTerms, searchOrder)
             self.actionSearch.setVisible(True)
         else:
-            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&vq=%s&orderby=%s" % (username, searchTerms, searchOrder)
+            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&vq=%s&racy=include&orderby=%s" % (username, searchTerms, searchOrder)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
