@@ -31,8 +31,8 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow) 
         self.setAutoDisplayOrientation()
         self.youtubeLabel = QLabel(self)
-        self.youtubeLabel.setGeometry(QRect(10, 10, 150, 90))
-        self.youtubeLabel.setPixmap(QPixmap(":/images/ui-images/youtube.png"))
+        self.youtubeLabel.setGeometry(QRect(10, 10, 294, 87))
+        self.youtubeLabel.setPixmap(QPixmap(":/images/ui-images/banner.png"))
         self.youtubeLabel.setScaledContents(True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.orientationChanged()
@@ -45,7 +45,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         taskQueueLength = len(YouTubeVideoDownloader.taskQueue)
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
-            self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
+            self.actionDownloads.setText("Downloads (%d videos)" % taskQueueLength)
         self.show()
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
         self.youtubeLogin()
@@ -112,6 +112,8 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             YouTubeAPISettings.userDict = settings.value("userDict",  {}).toPyObject()
             YouTubeAPISettings.defaultUser = settings.value("defaultUser",  "").toString()
             YouTubeAPISettings.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
+            YouTubeAPISettings.categoryFilter = settings.value("categoryFilter", "").toString()
+            YouTubeAPISettings.locationFilter = settings.value("locationFilter", "").toString()
             if VideoPlaybackSettings.playbackFormat in (17, 18):
                 VideoPlaybackSettings.playbackFormat = settings.value("playbackFormat",  18).toInt()[0]
             VideoDownloadSettings.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
@@ -142,6 +144,8 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             userDict = QVariant(YouTubeAPISettings.userDict)
             defaultUser = QVariant(YouTubeAPISettings.defaultUser)
             noAccountDialog = QVariant(YouTubeAPISettings.raiseNoAccountFoundDialog)
+            categoryFilter = QVariant(YouTubeAPISettings.categoryFilter)
+            locationFilter = QVariant(YouTubeAPISettings.locationFilter)
             playbackFormat = QVariant(VideoPlaybackSettings.playbackFormat)        
             downloadFolder = QVariant(VideoDownloadSettings.downloadFolder)
             downloadStatus = QVariant(VideoDownloadSettings.defaultTaskStatus)
@@ -158,6 +162,8 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             settings.setValue("userDict", userDict)
             settings.setValue("defaultUser", defaultUser)
             settings.setValue("noAccountDialog", noAccountDialog)
+            settings.setValue("categoryFilter", categoryFilter)
+            settings.setValue("locationFilter", locationFilter)
             settings.setValue("downloadFolder", downloadFolder)
             settings.setValue("downloadStatus", downloadStatus)
             settings.setValue("playbackFormat", playbackFormat)
@@ -213,7 +219,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         if queueLength > 0:
             self.actionGoToQueue.setVisible(True)
-            self.actionGoToQueue.setText("Queue (%s videos)" % unicode(queueLength))
+            self.actionGoToQueue.setText("Queue (%d videos)" % queueLength)
         else:
             self.actionGoToQueue.setVisible(False)
             
@@ -224,7 +230,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
-            self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
+            self.actionDownloads.setText("Downloads (%d videos)" % taskQueueLength)
         else:
             self.actionDownloads.setVisible(False)
 
