@@ -28,8 +28,8 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow) 
         self.setWindowTitle("My Channel")
         self.youtubeLabel = QLabel(self)
-        self.youtubeLabel.setGeometry(QRect(10, 10, 150, 90))
-        self.youtubeLabel.setPixmap(QPixmap(":/images/ui-images/youtube.png"))
+        self.youtubeLabel.setGeometry(QRect(10, 10, 294, 87))
+        self.youtubeLabel.setPixmap(QPixmap(":/images/ui-images/banner.png"))
         self.youtubeLabel.setScaledContents(True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged) 
         self.orientationChanged()
@@ -39,10 +39,14 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
             self.connect(button,  SIGNAL("released()"), self.changeButtonStyleSheet)
         self.keyPressEvent = self.showSearchDialog
         self.searchDialogRaised = False
+        queueLength = len(youtubeservice.YouTubeQueueFeed.playlist)
+        if queueLength > 0:
+            self.actionGoToQueue.setVisible(True)
+            self.actionGoToQueue.setText("Queue (%d videos)" % queueLength)
         taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
-            self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
+            self.actionDownloads.setText("Downloads (%d videos)" % taskQueueLength)
         if len(YouTubeAPISettings.userDict) <= 1:
             self.actionSwitchAccount.setVisible(False)
         self.show()
@@ -110,7 +114,7 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         """
         if queueLength > 0:
             self.actionGoToQueue.setVisible(True)
-            self.actionGoToQueue.setText("Queue (%s videos)" % unicode(queueLength))
+            self.actionGoToQueue.setText("Queue (%d videos)" % queueLength)
         else:
             self.actionGoToQueue.setVisible(False)
         self.emit(SIGNAL("queueChanged(int)"), queueLength)
@@ -122,7 +126,7 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         """
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
-            self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
+            self.actionDownloads.setText("Downloads (%d videos)" % taskQueueLength)
         else:
             self.actionDownloads.setVisible(False)
         self.emit(SIGNAL("downloadsChanged(int)"), taskQueueLength)
