@@ -244,6 +244,14 @@ class YouTubeVideoFeed(QThread):
         self.results = 0
         self.thumbcount = 0
         self.totalResults = 0
+        
+    def resetResultCount(self):
+        """
+        Resets the result and thumbnail count to zero.
+        """
+        self.videoList = []
+        self.results = 0
+        self.thumbcount = 0
     
     def getVideoFeed(self):
         """
@@ -293,10 +301,12 @@ class YouTubeVideoFeed(QThread):
 
     def run(self):
         self.emit(SIGNAL("feedCompleted(bool)"), True)
-        self.getVideoFeed() 
+        if self.results == 0:
+            self.getVideoFeed() 
         self.getVideoData()
         self.emit(SIGNAL("feedCompleted(bool)"), False)
         self.getThumbnails()
+        self.getVideoFeed()
 
 class YouTubeQueueFeed(QThread):
     """
